@@ -31,12 +31,13 @@
 #' @param bfile If this is provided then will use the API. Default = `NULL`
 #' @param plink_bin If `NULL` and `bfile` is not `NULL` then will detect 
 #' packaged plink binary for specific OS. Otherwise specify path to plink binary. 
-#' Default = `NULL`
+#' Default = `NULL`,
+#' @param ... Additional arguments passed to `ld_clump_local()`.
 #'
 #' @export
 #' @return Data frame
 ld_clump <- function(dat=NULL, clump_kb=10000, clump_r2=0.001, clump_p=0.99, 
-                     pop = "EUR", opengwas_jwt=get_opengwas_jwt(), bfile=NULL, plink_bin=NULL)
+                     pop = "EUR", opengwas_jwt=get_opengwas_jwt(), bfile=NULL, plink_bin=NULL, ...)
 {
 
 	stopifnot("rsid" %in% names(dat))
@@ -84,7 +85,7 @@ ld_clump <- function(dat=NULL, clump_kb=10000, clump_r2=0.001, clump_p=0.99,
 			if(is.null(bfile))
 			{
 			  message("Clumping ", ids[i], ", ", nrow(x), " variants, using ", pop, " population reference")
-			  res[[i]] <- ld_clump_api(x, clump_kb=clump_kb, clump_r2=clump_r2, clump_p=clump_p, pop=pop, opengwas_jwt=opengwas_jwt)
+			  res[[i]] <- ld_clump_api(x, clump_kb=clump_kb, clump_r2=clump_r2, clump_p=clump_p, pop=pop, opengwas_jwt=opengwas_jwt, ...)
 			} else {
 			  message("Clumping ", ids[i], ", ", nrow(x), " variants, using: ", bfile)
 				res[[i]] <- ld_clump_local(x, clump_kb=clump_kb, clump_r2=clump_r2, clump_p=clump_p, bfile=bfile, plink_bin=plink_bin)
@@ -106,8 +107,9 @@ ld_clump <- function(dat=NULL, clump_kb=10000, clump_r2=0.001, clump_p=0.99,
 #' @param pop Super-population to use as reference panel. Default = `"EUR"`. 
 #' Options are `"EUR"`, `"SAS"`, `"EAS"`, `"AFR"`, `"AMR"`
 #' @param opengwas_jwt Used to authenticate protected endpoints. Login to <https://api.opengwas.io> to obtain a jwt. Provide the jwt string here, or store in .Renviron under the keyname OPENGWAS_JWT.
+#' @param ... Additional arguments passed to `api_query()`.
 #' @return Data frame of only independent variants
-ld_clump_api <- function(dat, clump_kb=10000, clump_r2=0.1, clump_p, pop="EUR", opengwas_jwt=get_opengwas_jwt())
+ld_clump_api <- function(dat, clump_kb=10000, clump_r2=0.1, clump_p, pop="EUR", opengwas_jwt=get_opengwas_jwt(), ...)
 {
 	res <- api_query('ld/clump',
 			query = list(
@@ -118,7 +120,7 @@ ld_clump_api <- function(dat, clump_kb=10000, clump_r2=0.1, clump_p, pop="EUR",
 				kb = clump_kb,
 				pop = pop
 			),
-			opengwas_jwt=opengwas_jwt
+			opengwas_jwt=opengwas_jwt, ...
 		) %>% get_query_content()
 	y <- subset(dat, !dat[["rsid"]] %in% res)
 	if(nrow(y) > 0)
@@ -195,17 +197,18 @@ random_string <- function(n=1, len=6)
 #' @param pop Super-population to use as reference panel. Default = `"EUR"`. 
 #' Options are `"EUR"`, `"SAS"`, `"EAS"`, `"AFR"`, `"AMR"`
 #' @param opengwas_jwt Used to authenticate protected endpoints. Login to <https://api.opengwas.io> to obtain a jwt. Provide the jwt string here, or store in .Renviron under the keyname OPENGWAS_JWT.
+#' @param ... Additional arguments passed to `api_query()`.
 #'
 #' @export
 #' @return Array of rsids that are present in the LD reference panel
-ld_reflookup <- function(rsid, pop='EUR', opengwas_jwt=get_opengwas_jwt())
+ld_reflookup <- function(rsid, pop='EUR', opengwas_jwt=get_opengwas_jwt(), ...)
 {
 	res <- api_query('ld/reflookup',
 			query = list(
 				rsid = rsid,
 				pop = pop
 			),
-			opengwas_jwt=opengwas_jwt
+			opengwas_jwt=opengwas_jwt, ...
 		) %>% get_query_content()
 	if(length(res) == 0)
 	{
