@@ -1,6 +1,6 @@
 # skip()
-# skip_on_cran()
-# skip_on_ci()
+skip_on_cran()
+skip_on_ci()
 
 stat <- try(api_status())
 if (inherits(stat, c("try-error", "response"))) skip("Server issues")
@@ -10,5 +10,3 @@ test_that("status",
 	expect_true(is.list(stat))
 	expect_gte(length(stat), 2)
 })
-
-
